UK Qualifier Watford, England June 29th 2002 41 players Jon Cooper Deck Name: This deck will self destruct in 4 seconds.... Created by: Jon Cooper - jon.cooper@damovo.com I would probably drop the strained vitae supply, a hunting ground (maybe both), the arcane library and possibly the info highway. Maybe replace with 1-2 more cryptic missions or bit more bleed. Possibly another embrace or two? Have tried using Rastafarian ghoul but is too pricy and too fragile. Jon Crypt (12 cards, min=8, max=16, avg=3) -------------------------------------- 2x Sarah Cobbler 4 THA dom Tremere:1 1x Ignatius 4 aus dom tha Tremere:1 1x Thelonius 4 aus dom tha Tremere antitribu:2 1x Blythe Candeleria 3 THA aus Tremere:2 1x Brooke 3 dom tha Tremere antitribu:2 1x Dr. John Casey 3 aus tha Tremere:1 1x Jing Wei 3 dom tha Tremere:1 1x Heinrick Schlempt 2 tha Tremere antitribu:2 1x Magdelena Schaefer 2 THA Caitiff:2 1x Mustafa Rahman 2 dom Tremere:2 1x Roreca Quaid 2 tha Tremere:1 Library (89 cards) Master (20) 1x Academic Hunting Ground 1x Arcane Library 6x Blood Doll 1x Chantry 1x Information Highway 2x Society of Leopold 1x Strained Vitae Supply 6x Thaumaturgy 1x University Hunting Ground Action (36) 4x Computer Hacking 26x Cryptic Mission 6x Embrace, The Ally (2) 2x Thadius Zho Action Modifier (10) 4x Change of Target 6x Conditioning Reaction (11) 5x Deflection 6x Wake with Evening's Freshness Combat (10) 3x Burst of Sunlight 3x Dodge 4x Fake Out